@@ -5,14 +5,14 @@ import (
 	"os/signal"
 	"syscall"
 
-	"github.com/99designs/aws-vault/v6/server"
+	"github.com/99designs/aws-vault/v7/server"
 	"github.com/alecthomas/kingpin"
 )
 
 func ConfigureProxyCommand(app *kingpin.Application, a *AwsVault) {
 	stop := false
 
-	cmd := app.Command("proxy", "Start a proxy for the ec2 instance role server locally").
+	cmd := app.Command("proxy", "Start a proxy for the ec2 instance role server locally.").
 		Alias("server").
 		Hidden()
 
